@@ -7,11 +7,9 @@ NumericVector W_Cpp(const NumericVector& z, int branch);
 
 // [[Rcpp::export]]
 NumericVector W_gamma_Cpp(const NumericVector& z, double gamma, int branch) {
-  NumericVector Wgammaz(z.length());
   if (gamma == 0.0) {
-    Wgammaz = z;
+    return z;
   } else {
-    Wgammaz = W_Cpp(gamma * z, branch = branch) / gamma;
+    return W_Cpp(gamma * z, branch) / gamma;
   }
-  return Wgammaz;
 }
